/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2023, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
export declare enum IdentityDomainsApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class IdentityDomainsClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Create a user's API key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateApiKeyRequest
     * @return CreateApiKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateApiKey.ts.html |here} to see how to use CreateApiKey API.
     */
    createApiKey(createApiKeyRequest: requests.CreateApiKeyRequest): Promise<responses.CreateApiKeyResponse>;
    /**
     * Create an App
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAppRequest
     * @return CreateAppResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateApp.ts.html |here} to see how to use CreateApp API.
     */
    createApp(createAppRequest: requests.CreateAppRequest): Promise<responses.CreateAppResponse>;
    /**
     * Create an AppRole
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAppRoleRequest
     * @return CreateAppRoleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateAppRole.ts.html |here} to see how to use CreateAppRole API.
     */
    createAppRole(createAppRoleRequest: requests.CreateAppRoleRequest): Promise<responses.CreateAppRoleResponse>;
    /**
     * Create a user's Auth token.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAuthTokenRequest
     * @return CreateAuthTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateAuthToken.ts.html |here} to see how to use CreateAuthToken API.
     */
    createAuthToken(createAuthTokenRequest: requests.CreateAuthTokenRequest): Promise<responses.CreateAuthTokenResponse>;
    /**
     * Remove All Authentication Factor Channels for a User
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAuthenticationFactorsRemoverRequest
     * @return CreateAuthenticationFactorsRemoverResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateAuthenticationFactorsRemover.ts.html |here} to see how to use CreateAuthenticationFactorsRemover API.
     */
    createAuthenticationFactorsRemover(createAuthenticationFactorsRemoverRequest: requests.CreateAuthenticationFactorsRemoverRequest): Promise<responses.CreateAuthenticationFactorsRemoverResponse>;
    /**
     * Create a user's customer secret key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateCustomerSecretKeyRequest
     * @return CreateCustomerSecretKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateCustomerSecretKey.ts.html |here} to see how to use CreateCustomerSecretKey API.
     */
    createCustomerSecretKey(createCustomerSecretKeyRequest: requests.CreateCustomerSecretKeyRequest): Promise<responses.CreateCustomerSecretKeyResponse>;
    /**
     * Create a Dynamic Resource Group.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDynamicResourceGroupRequest
     * @return CreateDynamicResourceGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateDynamicResourceGroup.ts.html |here} to see how to use CreateDynamicResourceGroup API.
     */
    createDynamicResourceGroup(createDynamicResourceGroupRequest: requests.CreateDynamicResourceGroupRequest): Promise<responses.CreateDynamicResourceGroupResponse>;
    /**
     * Add a Grantee to an AppRole
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateGrantRequest
     * @return CreateGrantResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateGrant.ts.html |here} to see how to use CreateGrant API.
     */
    createGrant(createGrantRequest: requests.CreateGrantRequest): Promise<responses.CreateGrantResponse>;
    /**
     * Create a group.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateGroupRequest
     * @return CreateGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateGroup.ts.html |here} to see how to use CreateGroup API.
     */
    createGroup(createGroupRequest: requests.CreateGroupRequest): Promise<responses.CreateGroupResponse>;
    /**
     * Create an Identity Provider
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateIdentityProviderRequest
     * @return CreateIdentityProviderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateIdentityProvider.ts.html |here} to see how to use CreateIdentityProvider API.
     */
    createIdentityProvider(createIdentityProviderRequest: requests.CreateIdentityProviderRequest): Promise<responses.CreateIdentityProviderResponse>;
    /**
     * Self register a user.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMeRequest
     * @return CreateMeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMe.ts.html |here} to see how to use CreateMe API.
     */
    createMe(createMeRequest: requests.CreateMeRequest): Promise<responses.CreateMeResponse>;
    /**
     * Add a user's own API key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMyApiKeyRequest
     * @return CreateMyApiKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMyApiKey.ts.html |here} to see how to use CreateMyApiKey API.
     */
    createMyApiKey(createMyApiKeyRequest: requests.CreateMyApiKeyRequest): Promise<responses.CreateMyApiKeyResponse>;
    /**
     * Create a user's own Auth token.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMyAuthTokenRequest
     * @return CreateMyAuthTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMyAuthToken.ts.html |here} to see how to use CreateMyAuthToken API.
     */
    createMyAuthToken(createMyAuthTokenRequest: requests.CreateMyAuthTokenRequest): Promise<responses.CreateMyAuthTokenResponse>;
    /**
     * Initiate Self Service Enrollment using the Requested MFA Factor
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMyAuthenticationFactorInitiatorRequest
     * @return CreateMyAuthenticationFactorInitiatorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMyAuthenticationFactorInitiator.ts.html |here} to see how to use CreateMyAuthenticationFactorInitiator API.
     */
    createMyAuthenticationFactorInitiator(createMyAuthenticationFactorInitiatorRequest: requests.CreateMyAuthenticationFactorInitiatorRequest): Promise<responses.CreateMyAuthenticationFactorInitiatorResponse>;
    /**
     * Validate Self Service Enrollment using the Requested MFA Factor
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMyAuthenticationFactorValidatorRequest
     * @return CreateMyAuthenticationFactorValidatorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMyAuthenticationFactorValidator.ts.html |here} to see how to use CreateMyAuthenticationFactorValidator API.
     */
    createMyAuthenticationFactorValidator(createMyAuthenticationFactorValidatorRequest: requests.CreateMyAuthenticationFactorValidatorRequest): Promise<responses.CreateMyAuthenticationFactorValidatorResponse>;
    /**
     * Remove All Authentication Factor Channels for a User
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMyAuthenticationFactorsRemoverRequest
     * @return CreateMyAuthenticationFactorsRemoverResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMyAuthenticationFactorsRemover.ts.html |here} to see how to use CreateMyAuthenticationFactorsRemover API.
     */
    createMyAuthenticationFactorsRemover(createMyAuthenticationFactorsRemoverRequest: requests.CreateMyAuthenticationFactorsRemoverRequest): Promise<responses.CreateMyAuthenticationFactorsRemoverResponse>;
    /**
     * Add a user's own customer secret key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMyCustomerSecretKeyRequest
     * @return CreateMyCustomerSecretKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMyCustomerSecretKey.ts.html |here} to see how to use CreateMyCustomerSecretKey API.
     */
    createMyCustomerSecretKey(createMyCustomerSecretKeyRequest: requests.CreateMyCustomerSecretKeyRequest): Promise<responses.CreateMyCustomerSecretKeyResponse>;
    /**
     * Create a user's own OAuth2 client credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMyOAuth2ClientCredentialRequest
     * @return CreateMyOAuth2ClientCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMyOAuth2ClientCredential.ts.html |here} to see how to use CreateMyOAuth2ClientCredential API.
     */
    createMyOAuth2ClientCredential(createMyOAuth2ClientCredentialRequest: requests.CreateMyOAuth2ClientCredentialRequest): Promise<responses.CreateMyOAuth2ClientCredentialResponse>;
    /**
     * Create a Request
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMyRequestRequest
     * @return CreateMyRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMyRequest.ts.html |here} to see how to use CreateMyRequest API.
     */
    createMyRequest(createMyRequestRequest: requests.CreateMyRequestRequest): Promise<responses.CreateMyRequestResponse>;
    /**
     * Create a user's own SMTP credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMySmtpCredentialRequest
     * @return CreateMySmtpCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMySmtpCredential.ts.html |here} to see how to use CreateMySmtpCredential API.
     */
    createMySmtpCredential(createMySmtpCredentialRequest: requests.CreateMySmtpCredentialRequest): Promise<responses.CreateMySmtpCredentialResponse>;
    /**
     * Create a user's own support account.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMySupportAccountRequest
     * @return CreateMySupportAccountResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMySupportAccount.ts.html |here} to see how to use CreateMySupportAccount API.
     */
    createMySupportAccount(createMySupportAccountRequest: requests.CreateMySupportAccountRequest): Promise<responses.CreateMySupportAccountResponse>;
    /**
     * Create a user's own database (DB) credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMyUserDbCredentialRequest
     * @return CreateMyUserDbCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateMyUserDbCredential.ts.html |here} to see how to use CreateMyUserDbCredential API.
     */
    createMyUserDbCredential(createMyUserDbCredentialRequest: requests.CreateMyUserDbCredentialRequest): Promise<responses.CreateMyUserDbCredentialResponse>;
    /**
     * Add a user's OAuth2 client credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateOAuth2ClientCredentialRequest
     * @return CreateOAuth2ClientCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateOAuth2ClientCredential.ts.html |here} to see how to use CreateOAuth2ClientCredential API.
     */
    createOAuth2ClientCredential(createOAuth2ClientCredentialRequest: requests.CreateOAuth2ClientCredentialRequest): Promise<responses.CreateOAuth2ClientCredentialResponse>;
    /**
     * Create a password policy.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreatePasswordPolicyRequest
     * @return CreatePasswordPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreatePasswordPolicy.ts.html |here} to see how to use CreatePasswordPolicy API.
     */
    createPasswordPolicy(createPasswordPolicyRequest: requests.CreatePasswordPolicyRequest): Promise<responses.CreatePasswordPolicyResponse>;
    /**
     * Create a security question.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateSecurityQuestionRequest
     * @return CreateSecurityQuestionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateSecurityQuestion.ts.html |here} to see how to use CreateSecurityQuestion API.
     */
    createSecurityQuestion(createSecurityQuestionRequest: requests.CreateSecurityQuestionRequest): Promise<responses.CreateSecurityQuestionResponse>;
    /**
     * Create a user's SMTP credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateSmtpCredentialRequest
     * @return CreateSmtpCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateSmtpCredential.ts.html |here} to see how to use CreateSmtpCredential API.
     */
    createSmtpCredential(createSmtpCredentialRequest: requests.CreateSmtpCredentialRequest): Promise<responses.CreateSmtpCredentialResponse>;
    /**
     * Create a user.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateUserRequest
     * @return CreateUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateUser.ts.html |here} to see how to use CreateUser API.
     */
    createUser(createUserRequest: requests.CreateUserRequest): Promise<responses.CreateUserResponse>;
    /**
     * Create a user's database (DB) credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateUserDbCredentialRequest
     * @return CreateUserDbCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/CreateUserDbCredential.ts.html |here} to see how to use CreateUserDbCredential API.
     */
    createUserDbCredential(createUserDbCredentialRequest: requests.CreateUserDbCredentialRequest): Promise<responses.CreateUserDbCredentialResponse>;
    /**
     * Delete a user's API key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteApiKeyRequest
     * @return DeleteApiKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteApiKey.ts.html |here} to see how to use DeleteApiKey API.
     */
    deleteApiKey(deleteApiKeyRequest: requests.DeleteApiKeyRequest): Promise<responses.DeleteApiKeyResponse>;
    /**
     * Delete an App
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAppRequest
     * @return DeleteAppResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteApp.ts.html |here} to see how to use DeleteApp API.
     */
    deleteApp(deleteAppRequest: requests.DeleteAppRequest): Promise<responses.DeleteAppResponse>;
    /**
     * Delete an AppRole
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAppRoleRequest
     * @return DeleteAppRoleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteAppRole.ts.html |here} to see how to use DeleteAppRole API.
     */
    deleteAppRole(deleteAppRoleRequest: requests.DeleteAppRoleRequest): Promise<responses.DeleteAppRoleResponse>;
    /**
     * Delete a user's Auth token.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAuthTokenRequest
     * @return DeleteAuthTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteAuthToken.ts.html |here} to see how to use DeleteAuthToken API.
     */
    deleteAuthToken(deleteAuthTokenRequest: requests.DeleteAuthTokenRequest): Promise<responses.DeleteAuthTokenResponse>;
    /**
     * Delete a user's customer secret key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteCustomerSecretKeyRequest
     * @return DeleteCustomerSecretKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteCustomerSecretKey.ts.html |here} to see how to use DeleteCustomerSecretKey API.
     */
    deleteCustomerSecretKey(deleteCustomerSecretKeyRequest: requests.DeleteCustomerSecretKeyRequest): Promise<responses.DeleteCustomerSecretKeyResponse>;
    /**
     * Delete a Dynamic Resource Group.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDynamicResourceGroupRequest
     * @return DeleteDynamicResourceGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteDynamicResourceGroup.ts.html |here} to see how to use DeleteDynamicResourceGroup API.
     */
    deleteDynamicResourceGroup(deleteDynamicResourceGroupRequest: requests.DeleteDynamicResourceGroupRequest): Promise<responses.DeleteDynamicResourceGroupResponse>;
    /**
     * Remove a Grantee from an AppRole
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteGrantRequest
     * @return DeleteGrantResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteGrant.ts.html |here} to see how to use DeleteGrant API.
     */
    deleteGrant(deleteGrantRequest: requests.DeleteGrantRequest): Promise<responses.DeleteGrantResponse>;
    /**
     * Delete a group.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteGroupRequest
     * @return DeleteGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteGroup.ts.html |here} to see how to use DeleteGroup API.
     */
    deleteGroup(deleteGroupRequest: requests.DeleteGroupRequest): Promise<responses.DeleteGroupResponse>;
    /**
     * Delete an Identity Provider
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteIdentityProviderRequest
     * @return DeleteIdentityProviderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteIdentityProvider.ts.html |here} to see how to use DeleteIdentityProvider API.
     */
    deleteIdentityProvider(deleteIdentityProviderRequest: requests.DeleteIdentityProviderRequest): Promise<responses.DeleteIdentityProviderResponse>;
    /**
     * Delete a user's own API key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteMyApiKeyRequest
     * @return DeleteMyApiKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteMyApiKey.ts.html |here} to see how to use DeleteMyApiKey API.
     */
    deleteMyApiKey(deleteMyApiKeyRequest: requests.DeleteMyApiKeyRequest): Promise<responses.DeleteMyApiKeyResponse>;
    /**
     * Delete a user's own Auth token.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteMyAuthTokenRequest
     * @return DeleteMyAuthTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteMyAuthToken.ts.html |here} to see how to use DeleteMyAuthToken API.
     */
    deleteMyAuthToken(deleteMyAuthTokenRequest: requests.DeleteMyAuthTokenRequest): Promise<responses.DeleteMyAuthTokenResponse>;
    /**
     * Delete a user's own customer secret key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteMyCustomerSecretKeyRequest
     * @return DeleteMyCustomerSecretKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteMyCustomerSecretKey.ts.html |here} to see how to use DeleteMyCustomerSecretKey API.
     */
    deleteMyCustomerSecretKey(deleteMyCustomerSecretKeyRequest: requests.DeleteMyCustomerSecretKeyRequest): Promise<responses.DeleteMyCustomerSecretKeyResponse>;
    /**
     * Delete a Device
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteMyDeviceRequest
     * @return DeleteMyDeviceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteMyDevice.ts.html |here} to see how to use DeleteMyDevice API.
     */
    deleteMyDevice(deleteMyDeviceRequest: requests.DeleteMyDeviceRequest): Promise<responses.DeleteMyDeviceResponse>;
    /**
     * Delete a user's own OAuth2 client credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteMyOAuth2ClientCredentialRequest
     * @return DeleteMyOAuth2ClientCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteMyOAuth2ClientCredential.ts.html |here} to see how to use DeleteMyOAuth2ClientCredential API.
     */
    deleteMyOAuth2ClientCredential(deleteMyOAuth2ClientCredentialRequest: requests.DeleteMyOAuth2ClientCredentialRequest): Promise<responses.DeleteMyOAuth2ClientCredentialResponse>;
    /**
     * Delete a user's own SMTP credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteMySmtpCredentialRequest
     * @return DeleteMySmtpCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteMySmtpCredential.ts.html |here} to see how to use DeleteMySmtpCredential API.
     */
    deleteMySmtpCredential(deleteMySmtpCredentialRequest: requests.DeleteMySmtpCredentialRequest): Promise<responses.DeleteMySmtpCredentialResponse>;
    /**
     * Delete a user's own support account.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteMySupportAccountRequest
     * @return DeleteMySupportAccountResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteMySupportAccount.ts.html |here} to see how to use DeleteMySupportAccount API.
     */
    deleteMySupportAccount(deleteMySupportAccountRequest: requests.DeleteMySupportAccountRequest): Promise<responses.DeleteMySupportAccountResponse>;
    /**
     * Delete a Trusted User Agent
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteMyTrustedUserAgentRequest
     * @return DeleteMyTrustedUserAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteMyTrustedUserAgent.ts.html |here} to see how to use DeleteMyTrustedUserAgent API.
     */
    deleteMyTrustedUserAgent(deleteMyTrustedUserAgentRequest: requests.DeleteMyTrustedUserAgentRequest): Promise<responses.DeleteMyTrustedUserAgentResponse>;
    /**
     * Delete a user's own database (DB) credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteMyUserDbCredentialRequest
     * @return DeleteMyUserDbCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteMyUserDbCredential.ts.html |here} to see how to use DeleteMyUserDbCredential API.
     */
    deleteMyUserDbCredential(deleteMyUserDbCredentialRequest: requests.DeleteMyUserDbCredentialRequest): Promise<responses.DeleteMyUserDbCredentialResponse>;
    /**
     * Delete a user's OAuth2 client credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteOAuth2ClientCredentialRequest
     * @return DeleteOAuth2ClientCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteOAuth2ClientCredential.ts.html |here} to see how to use DeleteOAuth2ClientCredential API.
     */
    deleteOAuth2ClientCredential(deleteOAuth2ClientCredentialRequest: requests.DeleteOAuth2ClientCredentialRequest): Promise<responses.DeleteOAuth2ClientCredentialResponse>;
    /**
     * Delete a password policy.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeletePasswordPolicyRequest
     * @return DeletePasswordPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeletePasswordPolicy.ts.html |here} to see how to use DeletePasswordPolicy API.
     */
    deletePasswordPolicy(deletePasswordPolicyRequest: requests.DeletePasswordPolicyRequest): Promise<responses.DeletePasswordPolicyResponse>;
    /**
     * Delete a security question.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteSecurityQuestionRequest
     * @return DeleteSecurityQuestionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteSecurityQuestion.ts.html |here} to see how to use DeleteSecurityQuestion API.
     */
    deleteSecurityQuestion(deleteSecurityQuestionRequest: requests.DeleteSecurityQuestionRequest): Promise<responses.DeleteSecurityQuestionResponse>;
    /**
     * Delete a user's SMTP credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteSmtpCredentialRequest
     * @return DeleteSmtpCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteSmtpCredential.ts.html |here} to see how to use DeleteSmtpCredential API.
     */
    deleteSmtpCredential(deleteSmtpCredentialRequest: requests.DeleteSmtpCredentialRequest): Promise<responses.DeleteSmtpCredentialResponse>;
    /**
     * Delete a user.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteUserRequest
     * @return DeleteUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteUser.ts.html |here} to see how to use DeleteUser API.
     */
    deleteUser(deleteUserRequest: requests.DeleteUserRequest): Promise<responses.DeleteUserResponse>;
    /**
     * Delete a user's database (DB) credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteUserDbCredentialRequest
     * @return DeleteUserDbCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/DeleteUserDbCredential.ts.html |here} to see how to use DeleteUserDbCredential API.
     */
    deleteUserDbCredential(deleteUserDbCredentialRequest: requests.DeleteUserDbCredentialRequest): Promise<responses.DeleteUserDbCredentialResponse>;
    /**
     * Get Account Mgmt Info
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAccountMgmtInfoRequest
     * @return GetAccountMgmtInfoResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetAccountMgmtInfo.ts.html |here} to see how to use GetAccountMgmtInfo API.
     */
    getAccountMgmtInfo(getAccountMgmtInfoRequest: requests.GetAccountMgmtInfoRequest): Promise<responses.GetAccountMgmtInfoResponse>;
    /**
     * Get an account recovery setting.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAccountRecoverySettingRequest
     * @return GetAccountRecoverySettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetAccountRecoverySetting.ts.html |here} to see how to use GetAccountRecoverySetting API.
     */
    getAccountRecoverySetting(getAccountRecoverySettingRequest: requests.GetAccountRecoverySettingRequest): Promise<responses.GetAccountRecoverySettingResponse>;
    /**
     * Get a user's API key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetApiKeyRequest
     * @return GetApiKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetApiKey.ts.html |here} to see how to use GetApiKey API.
     */
    getApiKey(getApiKeyRequest: requests.GetApiKeyRequest): Promise<responses.GetApiKeyResponse>;
    /**
     * Get an App
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAppRequest
     * @return GetAppResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetApp.ts.html |here} to see how to use GetApp API.
     */
    getApp(getAppRequest: requests.GetAppRequest): Promise<responses.GetAppResponse>;
    /**
     * Get an AppRole
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAppRoleRequest
     * @return GetAppRoleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetAppRole.ts.html |here} to see how to use GetAppRole API.
     */
    getAppRole(getAppRoleRequest: requests.GetAppRoleRequest): Promise<responses.GetAppRoleResponse>;
    /**
     * Get a user's Auth token.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAuthTokenRequest
     * @return GetAuthTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetAuthToken.ts.html |here} to see how to use GetAuthToken API.
     */
    getAuthToken(getAuthTokenRequest: requests.GetAuthTokenRequest): Promise<responses.GetAuthTokenResponse>;
    /**
     * Get Authentication Factor Settings
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAuthenticationFactorSettingRequest
     * @return GetAuthenticationFactorSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetAuthenticationFactorSetting.ts.html |here} to see how to use GetAuthenticationFactorSetting API.
     */
    getAuthenticationFactorSetting(getAuthenticationFactorSettingRequest: requests.GetAuthenticationFactorSettingRequest): Promise<responses.GetAuthenticationFactorSettingResponse>;
    /**
     * Get a user's customer secret key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCustomerSecretKeyRequest
     * @return GetCustomerSecretKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetCustomerSecretKey.ts.html |here} to see how to use GetCustomerSecretKey API.
     */
    getCustomerSecretKey(getCustomerSecretKeyRequest: requests.GetCustomerSecretKeyRequest): Promise<responses.GetCustomerSecretKeyResponse>;
    /**
     * Get a Dynamic Resource Group.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDynamicResourceGroupRequest
     * @return GetDynamicResourceGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetDynamicResourceGroup.ts.html |here} to see how to use GetDynamicResourceGroup API.
     */
    getDynamicResourceGroup(getDynamicResourceGroupRequest: requests.GetDynamicResourceGroupRequest): Promise<responses.GetDynamicResourceGroupResponse>;
    /**
     * Get a Grant
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetGrantRequest
     * @return GetGrantResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetGrant.ts.html |here} to see how to use GetGrant API.
     */
    getGrant(getGrantRequest: requests.GetGrantRequest): Promise<responses.GetGrantResponse>;
    /**
     * Get a group. <b>Important:</b> The Group SEARCH and GET operations on users and members will throw an exception if the response has more than 10,000 members. To avoid the exception, use the pagination filter to GET or SEARCH group members.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetGroupRequest
     * @return GetGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetGroup.ts.html |here} to see how to use GetGroup API.
     */
    getGroup(getGroupRequest: requests.GetGroupRequest): Promise<responses.GetGroupResponse>;
    /**
     * Get an Identity Provider
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetIdentityProviderRequest
     * @return GetIdentityProviderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetIdentityProvider.ts.html |here} to see how to use GetIdentityProvider API.
     */
    getIdentityProvider(getIdentityProviderRequest: requests.GetIdentityProviderRequest): Promise<responses.GetIdentityProviderResponse>;
    /**
     * Get an Identity setting.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetIdentitySettingRequest
     * @return GetIdentitySettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetIdentitySetting.ts.html |here} to see how to use GetIdentitySetting API.
     */
    getIdentitySetting(getIdentitySettingRequest: requests.GetIdentitySettingRequest): Promise<responses.GetIdentitySettingResponse>;
    /**
     * Get KmsiSettings
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetKmsiSettingRequest
     * @return GetKmsiSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetKmsiSetting.ts.html |here} to see how to use GetKmsiSetting API.
     */
    getKmsiSetting(getKmsiSettingRequest: requests.GetKmsiSettingRequest): Promise<responses.GetKmsiSettingResponse>;
    /**
     * Get a user's own information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMeRequest
     * @return GetMeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetMe.ts.html |here} to see how to use GetMe API.
     */
    getMe(getMeRequest: requests.GetMeRequest): Promise<responses.GetMeResponse>;
    /**
     * Get a user's own API key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMyApiKeyRequest
     * @return GetMyApiKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetMyApiKey.ts.html |here} to see how to use GetMyApiKey API.
     */
    getMyApiKey(getMyApiKeyRequest: requests.GetMyApiKeyRequest): Promise<responses.GetMyApiKeyResponse>;
    /**
     * Get a user's own Auth token.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMyAuthTokenRequest
     * @return GetMyAuthTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetMyAuthToken.ts.html |here} to see how to use GetMyAuthToken API.
     */
    getMyAuthToken(getMyAuthTokenRequest: requests.GetMyAuthTokenRequest): Promise<responses.GetMyAuthTokenResponse>;
    /**
     * Get a user's own customer secret key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMyCustomerSecretKeyRequest
     * @return GetMyCustomerSecretKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetMyCustomerSecretKey.ts.html |here} to see how to use GetMyCustomerSecretKey API.
     */
    getMyCustomerSecretKey(getMyCustomerSecretKeyRequest: requests.GetMyCustomerSecretKeyRequest): Promise<responses.GetMyCustomerSecretKeyResponse>;
    /**
     * Get a Device
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMyDeviceRequest
     * @return GetMyDeviceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetMyDevice.ts.html |here} to see how to use GetMyDevice API.
     */
    getMyDevice(getMyDeviceRequest: requests.GetMyDeviceRequest): Promise<responses.GetMyDeviceResponse>;
    /**
     * Get a user's own OAuth2 client credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMyOAuth2ClientCredentialRequest
     * @return GetMyOAuth2ClientCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetMyOAuth2ClientCredential.ts.html |here} to see how to use GetMyOAuth2ClientCredential API.
     */
    getMyOAuth2ClientCredential(getMyOAuth2ClientCredentialRequest: requests.GetMyOAuth2ClientCredentialRequest): Promise<responses.GetMyOAuth2ClientCredentialResponse>;
    /**
     * Get a user's own SMTP credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMySmtpCredentialRequest
     * @return GetMySmtpCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetMySmtpCredential.ts.html |here} to see how to use GetMySmtpCredential API.
     */
    getMySmtpCredential(getMySmtpCredentialRequest: requests.GetMySmtpCredentialRequest): Promise<responses.GetMySmtpCredentialResponse>;
    /**
     * Get a user's own support account.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMySupportAccountRequest
     * @return GetMySupportAccountResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetMySupportAccount.ts.html |here} to see how to use GetMySupportAccount API.
     */
    getMySupportAccount(getMySupportAccountRequest: requests.GetMySupportAccountRequest): Promise<responses.GetMySupportAccountResponse>;
    /**
     * Get a Trusted User Agent
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMyTrustedUserAgentRequest
     * @return GetMyTrustedUserAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetMyTrustedUserAgent.ts.html |here} to see how to use GetMyTrustedUserAgent API.
     */
    getMyTrustedUserAgent(getMyTrustedUserAgentRequest: requests.GetMyTrustedUserAgentRequest): Promise<responses.GetMyTrustedUserAgentResponse>;
    /**
     * Get a user's own database (DB) credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMyUserDbCredentialRequest
     * @return GetMyUserDbCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetMyUserDbCredential.ts.html |here} to see how to use GetMyUserDbCredential API.
     */
    getMyUserDbCredential(getMyUserDbCredentialRequest: requests.GetMyUserDbCredentialRequest): Promise<responses.GetMyUserDbCredentialResponse>;
    /**
     * Get a user's OAuth2 client credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetOAuth2ClientCredentialRequest
     * @return GetOAuth2ClientCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetOAuth2ClientCredential.ts.html |here} to see how to use GetOAuth2ClientCredential API.
     */
    getOAuth2ClientCredential(getOAuth2ClientCredentialRequest: requests.GetOAuth2ClientCredentialRequest): Promise<responses.GetOAuth2ClientCredentialResponse>;
    /**
     * Get a password policy.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPasswordPolicyRequest
     * @return GetPasswordPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetPasswordPolicy.ts.html |here} to see how to use GetPasswordPolicy API.
     */
    getPasswordPolicy(getPasswordPolicyRequest: requests.GetPasswordPolicyRequest): Promise<responses.GetPasswordPolicyResponse>;
    /**
     * Get a security question.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSecurityQuestionRequest
     * @return GetSecurityQuestionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetSecurityQuestion.ts.html |here} to see how to use GetSecurityQuestion API.
     */
    getSecurityQuestion(getSecurityQuestionRequest: requests.GetSecurityQuestionRequest): Promise<responses.GetSecurityQuestionResponse>;
    /**
     * Get a security question setting.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSecurityQuestionSettingRequest
     * @return GetSecurityQuestionSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetSecurityQuestionSetting.ts.html |here} to see how to use GetSecurityQuestionSetting API.
     */
    getSecurityQuestionSetting(getSecurityQuestionSettingRequest: requests.GetSecurityQuestionSettingRequest): Promise<responses.GetSecurityQuestionSettingResponse>;
    /**
     * Get a user's SMTP credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSmtpCredentialRequest
     * @return GetSmtpCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetSmtpCredential.ts.html |here} to see how to use GetSmtpCredential API.
     */
    getSmtpCredential(getSmtpCredentialRequest: requests.GetSmtpCredentialRequest): Promise<responses.GetSmtpCredentialResponse>;
    /**
     * Get a user.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetUserRequest
     * @return GetUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetUser.ts.html |here} to see how to use GetUser API.
     */
    getUser(getUserRequest: requests.GetUserRequest): Promise<responses.GetUserResponse>;
    /**
     * Get User Schema Attribute Settings
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetUserAttributesSettingRequest
     * @return GetUserAttributesSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetUserAttributesSetting.ts.html |here} to see how to use GetUserAttributesSetting API.
     */
    getUserAttributesSetting(getUserAttributesSettingRequest: requests.GetUserAttributesSettingRequest): Promise<responses.GetUserAttributesSettingResponse>;
    /**
     * Get a user's database (DB) credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetUserDbCredentialRequest
     * @return GetUserDbCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/GetUserDbCredential.ts.html |here} to see how to use GetUserDbCredential API.
     */
    getUserDbCredential(getUserDbCredentialRequest: requests.GetUserDbCredentialRequest): Promise<responses.GetUserDbCredentialResponse>;
    /**
     * Search Account Mgmt Info
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAccountMgmtInfosRequest
     * @return ListAccountMgmtInfosResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListAccountMgmtInfos.ts.html |here} to see how to use ListAccountMgmtInfos API.
     */
    listAccountMgmtInfos(listAccountMgmtInfosRequest: requests.ListAccountMgmtInfosRequest): Promise<responses.ListAccountMgmtInfosResponse>;
    /**
     * Search for account recovery settings.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAccountRecoverySettingsRequest
     * @return ListAccountRecoverySettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListAccountRecoverySettings.ts.html |here} to see how to use ListAccountRecoverySettings API.
     */
    listAccountRecoverySettings(listAccountRecoverySettingsRequest: requests.ListAccountRecoverySettingsRequest): Promise<responses.ListAccountRecoverySettingsResponse>;
    /**
     * Search API keys.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListApiKeysRequest
     * @return ListApiKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListApiKeys.ts.html |here} to see how to use ListApiKeys API.
     */
    listApiKeys(listApiKeysRequest: requests.ListApiKeysRequest): Promise<responses.ListApiKeysResponse>;
    /**
     * Search AppRoles
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAppRolesRequest
     * @return ListAppRolesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListAppRoles.ts.html |here} to see how to use ListAppRoles API.
     */
    listAppRoles(listAppRolesRequest: requests.ListAppRolesRequest): Promise<responses.ListAppRolesResponse>;
    /**
     * Search Apps
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAppsRequest
     * @return ListAppsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListApps.ts.html |here} to see how to use ListApps API.
     */
    listApps(listAppsRequest: requests.ListAppsRequest): Promise<responses.ListAppsResponse>;
    /**
     * Search for Auth tokens.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAuthTokensRequest
     * @return ListAuthTokensResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListAuthTokens.ts.html |here} to see how to use ListAuthTokens API.
     */
    listAuthTokens(listAuthTokensRequest: requests.ListAuthTokensRequest): Promise<responses.ListAuthTokensResponse>;
    /**
     * Search Authentication Factor Settings
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAuthenticationFactorSettingsRequest
     * @return ListAuthenticationFactorSettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListAuthenticationFactorSettings.ts.html |here} to see how to use ListAuthenticationFactorSettings API.
     */
    listAuthenticationFactorSettings(listAuthenticationFactorSettingsRequest: requests.ListAuthenticationFactorSettingsRequest): Promise<responses.ListAuthenticationFactorSettingsResponse>;
    /**
     * Search for a user's customer secret keys.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListCustomerSecretKeysRequest
     * @return ListCustomerSecretKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListCustomerSecretKeys.ts.html |here} to see how to use ListCustomerSecretKeys API.
     */
    listCustomerSecretKeys(listCustomerSecretKeysRequest: requests.ListCustomerSecretKeysRequest): Promise<responses.ListCustomerSecretKeysResponse>;
    /**
     * Search for Dynamic Resource Groups.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDynamicResourceGroupsRequest
     * @return ListDynamicResourceGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListDynamicResourceGroups.ts.html |here} to see how to use ListDynamicResourceGroups API.
     */
    listDynamicResourceGroups(listDynamicResourceGroupsRequest: requests.ListDynamicResourceGroupsRequest): Promise<responses.ListDynamicResourceGroupsResponse>;
    /**
     * Search Grants
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListGrantsRequest
     * @return ListGrantsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListGrants.ts.html |here} to see how to use ListGrants API.
     */
    listGrants(listGrantsRequest: requests.ListGrantsRequest): Promise<responses.ListGrantsResponse>;
    /**
     * Search for groups. <b>Important:</b> The Group SEARCH and GET operations on users and members will throw an exception if the response has more than 10,000 members. To avoid the exception, use the pagination filter to GET or SEARCH group members.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListGroupsRequest
     * @return ListGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListGroups.ts.html |here} to see how to use ListGroups API.
     */
    listGroups(listGroupsRequest: requests.ListGroupsRequest): Promise<responses.ListGroupsResponse>;
    /**
     * Search Identity Providers
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListIdentityProvidersRequest
     * @return ListIdentityProvidersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListIdentityProviders.ts.html |here} to see how to use ListIdentityProviders API.
     */
    listIdentityProviders(listIdentityProvidersRequest: requests.ListIdentityProvidersRequest): Promise<responses.ListIdentityProvidersResponse>;
    /**
     * Search for Identity settings.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListIdentitySettingsRequest
     * @return ListIdentitySettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListIdentitySettings.ts.html |here} to see how to use ListIdentitySettings API.
     */
    listIdentitySettings(listIdentitySettingsRequest: requests.ListIdentitySettingsRequest): Promise<responses.ListIdentitySettingsResponse>;
    /**
     * Search KmsiSettings
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListKmsiSettingsRequest
     * @return ListKmsiSettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListKmsiSettings.ts.html |here} to see how to use ListKmsiSettings API.
     */
    listKmsiSettings(listKmsiSettingsRequest: requests.ListKmsiSettingsRequest): Promise<responses.ListKmsiSettingsResponse>;
    /**
     * Search for a user's own API key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMyApiKeysRequest
     * @return ListMyApiKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMyApiKeys.ts.html |here} to see how to use ListMyApiKeys API.
     */
    listMyApiKeys(listMyApiKeysRequest: requests.ListMyApiKeysRequest): Promise<responses.ListMyApiKeysResponse>;
    /**
     * Search My Apps
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMyAppsRequest
     * @return ListMyAppsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMyApps.ts.html |here} to see how to use ListMyApps API.
     */
    listMyApps(listMyAppsRequest: requests.ListMyAppsRequest): Promise<responses.ListMyAppsResponse>;
    /**
     * Search for a user's own Auth token.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMyAuthTokensRequest
     * @return ListMyAuthTokensResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMyAuthTokens.ts.html |here} to see how to use ListMyAuthTokens API.
     */
    listMyAuthTokens(listMyAuthTokensRequest: requests.ListMyAuthTokensRequest): Promise<responses.ListMyAuthTokensResponse>;
    /**
     * Search for a user's own customer secret key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMyCustomerSecretKeysRequest
     * @return ListMyCustomerSecretKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMyCustomerSecretKeys.ts.html |here} to see how to use ListMyCustomerSecretKeys API.
     */
    listMyCustomerSecretKeys(listMyCustomerSecretKeysRequest: requests.ListMyCustomerSecretKeysRequest): Promise<responses.ListMyCustomerSecretKeysResponse>;
    /**
     * Search Devices
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMyDevicesRequest
     * @return ListMyDevicesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMyDevices.ts.html |here} to see how to use ListMyDevices API.
     */
    listMyDevices(listMyDevicesRequest: requests.ListMyDevicesRequest): Promise<responses.ListMyDevicesResponse>;
    /**
     * Search for 'My Groups'.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMyGroupsRequest
     * @return ListMyGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMyGroups.ts.html |here} to see how to use ListMyGroups API.
     */
    listMyGroups(listMyGroupsRequest: requests.ListMyGroupsRequest): Promise<responses.ListMyGroupsResponse>;
    /**
     * Search for a user's own OAuth2 client credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMyOAuth2ClientCredentialsRequest
     * @return ListMyOAuth2ClientCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMyOAuth2ClientCredentials.ts.html |here} to see how to use ListMyOAuth2ClientCredentials API.
     */
    listMyOAuth2ClientCredentials(listMyOAuth2ClientCredentialsRequest: requests.ListMyOAuth2ClientCredentialsRequest): Promise<responses.ListMyOAuth2ClientCredentialsResponse>;
    /**
     * Search My Requestable Groups
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMyRequestableGroupsRequest
     * @return ListMyRequestableGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMyRequestableGroups.ts.html |here} to see how to use ListMyRequestableGroups API.
     */
    listMyRequestableGroups(listMyRequestableGroupsRequest: requests.ListMyRequestableGroupsRequest): Promise<responses.ListMyRequestableGroupsResponse>;
    /**
     * Search My Requests
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMyRequestsRequest
     * @return ListMyRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMyRequests.ts.html |here} to see how to use ListMyRequests API.
     */
    listMyRequests(listMyRequestsRequest: requests.ListMyRequestsRequest): Promise<responses.ListMyRequestsResponse>;
    /**
     * Search for a user's own SMTP credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMySmtpCredentialsRequest
     * @return ListMySmtpCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMySmtpCredentials.ts.html |here} to see how to use ListMySmtpCredentials API.
     */
    listMySmtpCredentials(listMySmtpCredentialsRequest: requests.ListMySmtpCredentialsRequest): Promise<responses.ListMySmtpCredentialsResponse>;
    /**
     * Search for a user's own support account.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMySupportAccountsRequest
     * @return ListMySupportAccountsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMySupportAccounts.ts.html |here} to see how to use ListMySupportAccounts API.
     */
    listMySupportAccounts(listMySupportAccountsRequest: requests.ListMySupportAccountsRequest): Promise<responses.ListMySupportAccountsResponse>;
    /**
     * Search Trusted User Agents
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMyTrustedUserAgentsRequest
     * @return ListMyTrustedUserAgentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMyTrustedUserAgents.ts.html |here} to see how to use ListMyTrustedUserAgents API.
     */
    listMyTrustedUserAgents(listMyTrustedUserAgentsRequest: requests.ListMyTrustedUserAgentsRequest): Promise<responses.ListMyTrustedUserAgentsResponse>;
    /**
     * Search for a user's own database (DB) credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMyUserDbCredentialsRequest
     * @return ListMyUserDbCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListMyUserDbCredentials.ts.html |here} to see how to use ListMyUserDbCredentials API.
     */
    listMyUserDbCredentials(listMyUserDbCredentialsRequest: requests.ListMyUserDbCredentialsRequest): Promise<responses.ListMyUserDbCredentialsResponse>;
    /**
     * Search for a user's OAuth2 client credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListOAuth2ClientCredentialsRequest
     * @return ListOAuth2ClientCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListOAuth2ClientCredentials.ts.html |here} to see how to use ListOAuth2ClientCredentials API.
     */
    listOAuth2ClientCredentials(listOAuth2ClientCredentialsRequest: requests.ListOAuth2ClientCredentialsRequest): Promise<responses.ListOAuth2ClientCredentialsResponse>;
    /**
     * Search for password policies.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPasswordPoliciesRequest
     * @return ListPasswordPoliciesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListPasswordPolicies.ts.html |here} to see how to use ListPasswordPolicies API.
     */
    listPasswordPolicies(listPasswordPoliciesRequest: requests.ListPasswordPoliciesRequest): Promise<responses.ListPasswordPoliciesResponse>;
    /**
     * Search Resource Type Schema Attributes
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListResourceTypeSchemaAttributesRequest
     * @return ListResourceTypeSchemaAttributesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListResourceTypeSchemaAttributes.ts.html |here} to see how to use ListResourceTypeSchemaAttributes API.
     */
    listResourceTypeSchemaAttributes(listResourceTypeSchemaAttributesRequest: requests.ListResourceTypeSchemaAttributesRequest): Promise<responses.ListResourceTypeSchemaAttributesResponse>;
    /**
     * Search for security question settings.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSecurityQuestionSettingsRequest
     * @return ListSecurityQuestionSettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListSecurityQuestionSettings.ts.html |here} to see how to use ListSecurityQuestionSettings API.
     */
    listSecurityQuestionSettings(listSecurityQuestionSettingsRequest: requests.ListSecurityQuestionSettingsRequest): Promise<responses.ListSecurityQuestionSettingsResponse>;
    /**
     * Search for security questions.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSecurityQuestionsRequest
     * @return ListSecurityQuestionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListSecurityQuestions.ts.html |here} to see how to use ListSecurityQuestions API.
     */
    listSecurityQuestions(listSecurityQuestionsRequest: requests.ListSecurityQuestionsRequest): Promise<responses.ListSecurityQuestionsResponse>;
    /**
     * Search for SMTP credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSmtpCredentialsRequest
     * @return ListSmtpCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListSmtpCredentials.ts.html |here} to see how to use ListSmtpCredentials API.
     */
    listSmtpCredentials(listSmtpCredentialsRequest: requests.ListSmtpCredentialsRequest): Promise<responses.ListSmtpCredentialsResponse>;
    /**
     * Search User Schema Attribute Settings
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListUserAttributesSettingsRequest
     * @return ListUserAttributesSettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListUserAttributesSettings.ts.html |here} to see how to use ListUserAttributesSettings API.
     */
    listUserAttributesSettings(listUserAttributesSettingsRequest: requests.ListUserAttributesSettingsRequest): Promise<responses.ListUserAttributesSettingsResponse>;
    /**
     * Search for a user's database (DB) credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListUserDbCredentialsRequest
     * @return ListUserDbCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListUserDbCredentials.ts.html |here} to see how to use ListUserDbCredentials API.
     */
    listUserDbCredentials(listUserDbCredentialsRequest: requests.ListUserDbCredentialsRequest): Promise<responses.ListUserDbCredentialsResponse>;
    /**
     * Search for users.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListUsersRequest
     * @return ListUsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/ListUsers.ts.html |here} to see how to use ListUsers API.
     */
    listUsers(listUsersRequest: requests.ListUsersRequest): Promise<responses.ListUsersResponse>;
    /**
     * Update an account recovery setting.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchAccountRecoverySettingRequest
     * @return PatchAccountRecoverySettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchAccountRecoverySetting.ts.html |here} to see how to use PatchAccountRecoverySetting API.
     */
    patchAccountRecoverySetting(patchAccountRecoverySettingRequest: requests.PatchAccountRecoverySettingRequest): Promise<responses.PatchAccountRecoverySettingResponse>;
    /**
     * Update a user's API key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchApiKeyRequest
     * @return PatchApiKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchApiKey.ts.html |here} to see how to use PatchApiKey API.
     */
    patchApiKey(patchApiKeyRequest: requests.PatchApiKeyRequest): Promise<responses.PatchApiKeyResponse>;
    /**
     * Update an App
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchAppRequest
     * @return PatchAppResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchApp.ts.html |here} to see how to use PatchApp API.
     */
    patchApp(patchAppRequest: requests.PatchAppRequest): Promise<responses.PatchAppResponse>;
    /**
     * Update an AppRole
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchAppRoleRequest
     * @return PatchAppRoleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchAppRole.ts.html |here} to see how to use PatchAppRole API.
     */
    patchAppRole(patchAppRoleRequest: requests.PatchAppRoleRequest): Promise<responses.PatchAppRoleResponse>;
    /**
     * Update a user's Auth token.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchAuthTokenRequest
     * @return PatchAuthTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchAuthToken.ts.html |here} to see how to use PatchAuthToken API.
     */
    patchAuthToken(patchAuthTokenRequest: requests.PatchAuthTokenRequest): Promise<responses.PatchAuthTokenResponse>;
    /**
     * Update a user's customer secret key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchCustomerSecretKeyRequest
     * @return PatchCustomerSecretKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchCustomerSecretKey.ts.html |here} to see how to use PatchCustomerSecretKey API.
     */
    patchCustomerSecretKey(patchCustomerSecretKeyRequest: requests.PatchCustomerSecretKeyRequest): Promise<responses.PatchCustomerSecretKeyResponse>;
    /**
     * Update a Dynamic Resource Group.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchDynamicResourceGroupRequest
     * @return PatchDynamicResourceGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchDynamicResourceGroup.ts.html |here} to see how to use PatchDynamicResourceGroup API.
     */
    patchDynamicResourceGroup(patchDynamicResourceGroupRequest: requests.PatchDynamicResourceGroupRequest): Promise<responses.PatchDynamicResourceGroupResponse>;
    /**
     * Update a Grant
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchGrantRequest
     * @return PatchGrantResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchGrant.ts.html |here} to see how to use PatchGrant API.
     */
    patchGrant(patchGrantRequest: requests.PatchGrantRequest): Promise<responses.PatchGrantResponse>;
    /**
     * Update a group.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchGroupRequest
     * @return PatchGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchGroup.ts.html |here} to see how to use PatchGroup API.
     */
    patchGroup(patchGroupRequest: requests.PatchGroupRequest): Promise<responses.PatchGroupResponse>;
    /**
     * Update an Identity Provider
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchIdentityProviderRequest
     * @return PatchIdentityProviderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchIdentityProvider.ts.html |here} to see how to use PatchIdentityProvider API.
     */
    patchIdentityProvider(patchIdentityProviderRequest: requests.PatchIdentityProviderRequest): Promise<responses.PatchIdentityProviderResponse>;
    /**
     * Update an Identity setting.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchIdentitySettingRequest
     * @return PatchIdentitySettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchIdentitySetting.ts.html |here} to see how to use PatchIdentitySetting API.
     */
    patchIdentitySetting(patchIdentitySettingRequest: requests.PatchIdentitySettingRequest): Promise<responses.PatchIdentitySettingResponse>;
    /**
     * Update a Setting
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchKmsiSettingRequest
     * @return PatchKmsiSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchKmsiSetting.ts.html |here} to see how to use PatchKmsiSetting API.
     */
    patchKmsiSetting(patchKmsiSettingRequest: requests.PatchKmsiSettingRequest): Promise<responses.PatchKmsiSettingResponse>;
    /**
     * Update a user's own information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchMeRequest
     * @return PatchMeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchMe.ts.html |here} to see how to use PatchMe API.
     */
    patchMe(patchMeRequest: requests.PatchMeRequest): Promise<responses.PatchMeResponse>;
    /**
     * Update a user's own API key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchMyApiKeyRequest
     * @return PatchMyApiKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchMyApiKey.ts.html |here} to see how to use PatchMyApiKey API.
     */
    patchMyApiKey(patchMyApiKeyRequest: requests.PatchMyApiKeyRequest): Promise<responses.PatchMyApiKeyResponse>;
    /**
     * Update a user's own Auth token.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchMyAuthTokenRequest
     * @return PatchMyAuthTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchMyAuthToken.ts.html |here} to see how to use PatchMyAuthToken API.
     */
    patchMyAuthToken(patchMyAuthTokenRequest: requests.PatchMyAuthTokenRequest): Promise<responses.PatchMyAuthTokenResponse>;
    /**
     * Update a user's own customer secret key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchMyCustomerSecretKeyRequest
     * @return PatchMyCustomerSecretKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchMyCustomerSecretKey.ts.html |here} to see how to use PatchMyCustomerSecretKey API.
     */
    patchMyCustomerSecretKey(patchMyCustomerSecretKeyRequest: requests.PatchMyCustomerSecretKeyRequest): Promise<responses.PatchMyCustomerSecretKeyResponse>;
    /**
     * Update a Device
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchMyDeviceRequest
     * @return PatchMyDeviceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchMyDevice.ts.html |here} to see how to use PatchMyDevice API.
     */
    patchMyDevice(patchMyDeviceRequest: requests.PatchMyDeviceRequest): Promise<responses.PatchMyDeviceResponse>;
    /**
     * Update a user's own OAuth2 client credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchMyOAuth2ClientCredentialRequest
     * @return PatchMyOAuth2ClientCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchMyOAuth2ClientCredential.ts.html |here} to see how to use PatchMyOAuth2ClientCredential API.
     */
    patchMyOAuth2ClientCredential(patchMyOAuth2ClientCredentialRequest: requests.PatchMyOAuth2ClientCredentialRequest): Promise<responses.PatchMyOAuth2ClientCredentialResponse>;
    /**
     * Update a user's own SMTP credential.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchMySmtpCredentialRequest
     * @return PatchMySmtpCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchMySmtpCredential.ts.html |here} to see how to use PatchMySmtpCredential API.
     */
    patchMySmtpCredential(patchMySmtpCredentialRequest: requests.PatchMySmtpCredentialRequest): Promise<responses.PatchMySmtpCredentialResponse>;
    /**
     * Update a user's OAuth2 client credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchOAuth2ClientCredentialRequest
     * @return PatchOAuth2ClientCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchOAuth2ClientCredential.ts.html |here} to see how to use PatchOAuth2ClientCredential API.
     */
    patchOAuth2ClientCredential(patchOAuth2ClientCredentialRequest: requests.PatchOAuth2ClientCredentialRequest): Promise<responses.PatchOAuth2ClientCredentialResponse>;
    /**
     * Update a password policy.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchPasswordPolicyRequest
     * @return PatchPasswordPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchPasswordPolicy.ts.html |here} to see how to use PatchPasswordPolicy API.
     */
    patchPasswordPolicy(patchPasswordPolicyRequest: requests.PatchPasswordPolicyRequest): Promise<responses.PatchPasswordPolicyResponse>;
    /**
     * Update a security question.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchSecurityQuestionRequest
     * @return PatchSecurityQuestionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchSecurityQuestion.ts.html |here} to see how to use PatchSecurityQuestion API.
     */
    patchSecurityQuestion(patchSecurityQuestionRequest: requests.PatchSecurityQuestionRequest): Promise<responses.PatchSecurityQuestionResponse>;
    /**
     * Update a security question setting.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchSecurityQuestionSettingRequest
     * @return PatchSecurityQuestionSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchSecurityQuestionSetting.ts.html |here} to see how to use PatchSecurityQuestionSetting API.
     */
    patchSecurityQuestionSetting(patchSecurityQuestionSettingRequest: requests.PatchSecurityQuestionSettingRequest): Promise<responses.PatchSecurityQuestionSettingResponse>;
    /**
     * Update a user's SMTP credentials.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchSmtpCredentialRequest
     * @return PatchSmtpCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchSmtpCredential.ts.html |here} to see how to use PatchSmtpCredential API.
     */
    patchSmtpCredential(patchSmtpCredentialRequest: requests.PatchSmtpCredentialRequest): Promise<responses.PatchSmtpCredentialResponse>;
    /**
     * Update a user.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchUserRequest
     * @return PatchUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchUser.ts.html |here} to see how to use PatchUser API.
     */
    patchUser(patchUserRequest: requests.PatchUserRequest): Promise<responses.PatchUserResponse>;
    /**
     * Update User Schema Attribute Settings
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PatchUserAttributesSettingRequest
     * @return PatchUserAttributesSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PatchUserAttributesSetting.ts.html |here} to see how to use PatchUserAttributesSetting API.
     */
    patchUserAttributesSetting(patchUserAttributesSettingRequest: requests.PatchUserAttributesSettingRequest): Promise<responses.PatchUserAttributesSettingResponse>;
    /**
     * Replace an account recovery setting.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutAccountRecoverySettingRequest
     * @return PutAccountRecoverySettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutAccountRecoverySetting.ts.html |here} to see how to use PutAccountRecoverySetting API.
     */
    putAccountRecoverySetting(putAccountRecoverySettingRequest: requests.PutAccountRecoverySettingRequest): Promise<responses.PutAccountRecoverySettingResponse>;
    /**
     * Replace an App
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutAppRequest
     * @return PutAppResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutApp.ts.html |here} to see how to use PutApp API.
     */
    putApp(putAppRequest: requests.PutAppRequest): Promise<responses.PutAppResponse>;
    /**
     * Activate/Deactivate an App
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutAppStatusChangerRequest
     * @return PutAppStatusChangerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutAppStatusChanger.ts.html |here} to see how to use PutAppStatusChanger API.
     */
    putAppStatusChanger(putAppStatusChangerRequest: requests.PutAppStatusChangerRequest): Promise<responses.PutAppStatusChangerResponse>;
    /**
     * Replace Authentication Factor Settings
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutAuthenticationFactorSettingRequest
     * @return PutAuthenticationFactorSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutAuthenticationFactorSetting.ts.html |here} to see how to use PutAuthenticationFactorSetting API.
     */
    putAuthenticationFactorSetting(putAuthenticationFactorSettingRequest: requests.PutAuthenticationFactorSettingRequest): Promise<responses.PutAuthenticationFactorSettingResponse>;
    /**
     * Replace a Dynamic Resource Group.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutDynamicResourceGroupRequest
     * @return PutDynamicResourceGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutDynamicResourceGroup.ts.html |here} to see how to use PutDynamicResourceGroup API.
     */
    putDynamicResourceGroup(putDynamicResourceGroupRequest: requests.PutDynamicResourceGroupRequest): Promise<responses.PutDynamicResourceGroupResponse>;
    /**
     * Replace a group.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutGroupRequest
     * @return PutGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutGroup.ts.html |here} to see how to use PutGroup API.
     */
    putGroup(putGroupRequest: requests.PutGroupRequest): Promise<responses.PutGroupResponse>;
    /**
     * Replace an Identity Provider
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutIdentityProviderRequest
     * @return PutIdentityProviderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutIdentityProvider.ts.html |here} to see how to use PutIdentityProvider API.
     */
    putIdentityProvider(putIdentityProviderRequest: requests.PutIdentityProviderRequest): Promise<responses.PutIdentityProviderResponse>;
    /**
     * Replace an Identity setting.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutIdentitySettingRequest
     * @return PutIdentitySettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutIdentitySetting.ts.html |here} to see how to use PutIdentitySetting API.
     */
    putIdentitySetting(putIdentitySettingRequest: requests.PutIdentitySettingRequest): Promise<responses.PutIdentitySettingResponse>;
    /**
     * Replace KmsiSettings
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutKmsiSettingRequest
     * @return PutKmsiSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutKmsiSetting.ts.html |here} to see how to use PutKmsiSetting API.
     */
    putKmsiSetting(putKmsiSettingRequest: requests.PutKmsiSettingRequest): Promise<responses.PutKmsiSettingResponse>;
    /**
     * Replace a user's own information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutMeRequest
     * @return PutMeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutMe.ts.html |here} to see how to use PutMe API.
     */
    putMe(putMeRequest: requests.PutMeRequest): Promise<responses.PutMeResponse>;
    /**
     * Update a user's own password.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutMePasswordChangerRequest
     * @return PutMePasswordChangerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutMePasswordChanger.ts.html |here} to see how to use PutMePasswordChanger API.
     */
    putMePasswordChanger(putMePasswordChangerRequest: requests.PutMePasswordChangerRequest): Promise<responses.PutMePasswordChangerResponse>;
    /**
     * Replace a password policy.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutPasswordPolicyRequest
     * @return PutPasswordPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutPasswordPolicy.ts.html |here} to see how to use PutPasswordPolicy API.
     */
    putPasswordPolicy(putPasswordPolicyRequest: requests.PutPasswordPolicyRequest): Promise<responses.PutPasswordPolicyResponse>;
    /**
     * Replace a security question setting.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutSecurityQuestionSettingRequest
     * @return PutSecurityQuestionSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutSecurityQuestionSetting.ts.html |here} to see how to use PutSecurityQuestionSetting API.
     */
    putSecurityQuestionSetting(putSecurityQuestionSettingRequest: requests.PutSecurityQuestionSettingRequest): Promise<responses.PutSecurityQuestionSettingResponse>;
    /**
     * Replace a user.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutUserRequest
     * @return PutUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutUser.ts.html |here} to see how to use PutUser API.
     */
    putUser(putUserRequest: requests.PutUserRequest): Promise<responses.PutUserResponse>;
    /**
     * Change a user's capabilities.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutUserCapabilitiesChangerRequest
     * @return PutUserCapabilitiesChangerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutUserCapabilitiesChanger.ts.html |here} to see how to use PutUserCapabilitiesChanger API.
     */
    putUserCapabilitiesChanger(putUserCapabilitiesChangerRequest: requests.PutUserCapabilitiesChangerRequest): Promise<responses.PutUserCapabilitiesChangerResponse>;
    /**
     * Change a user's password to a known value.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutUserPasswordChangerRequest
     * @return PutUserPasswordChangerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutUserPasswordChanger.ts.html |here} to see how to use PutUserPasswordChanger API.
     */
    putUserPasswordChanger(putUserPasswordChangerRequest: requests.PutUserPasswordChangerRequest): Promise<responses.PutUserPasswordChangerResponse>;
    /**
     * Reset a user's password to a randomly-generated value.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutUserPasswordResetterRequest
     * @return PutUserPasswordResetterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutUserPasswordResetter.ts.html |here} to see how to use PutUserPasswordResetter API.
     */
    putUserPasswordResetter(putUserPasswordResetterRequest: requests.PutUserPasswordResetterRequest): Promise<responses.PutUserPasswordResetterResponse>;
    /**
     * Change a user's status.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PutUserStatusChangerRequest
     * @return PutUserStatusChangerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/PutUserStatusChanger.ts.html |here} to see how to use PutUserStatusChanger API.
     */
    putUserStatusChanger(putUserStatusChangerRequest: requests.PutUserStatusChangerRequest): Promise<responses.PutUserStatusChangerResponse>;
    /**
     * Search Account Mgmt Info Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchAccountMgmtInfosRequest
     * @return SearchAccountMgmtInfosResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchAccountMgmtInfos.ts.html |here} to see how to use SearchAccountMgmtInfos API.
     */
    searchAccountMgmtInfos(searchAccountMgmtInfosRequest: requests.SearchAccountMgmtInfosRequest): Promise<responses.SearchAccountMgmtInfosResponse>;
    /**
     * Search ApiKeys Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchApiKeysRequest
     * @return SearchApiKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchApiKeys.ts.html |here} to see how to use SearchApiKeys API.
     */
    searchApiKeys(searchApiKeysRequest: requests.SearchApiKeysRequest): Promise<responses.SearchApiKeysResponse>;
    /**
     * Search AppRoles Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchAppRolesRequest
     * @return SearchAppRolesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchAppRoles.ts.html |here} to see how to use SearchAppRoles API.
     */
    searchAppRoles(searchAppRolesRequest: requests.SearchAppRolesRequest): Promise<responses.SearchAppRolesResponse>;
    /**
     * Search Apps Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchAppsRequest
     * @return SearchAppsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchApps.ts.html |here} to see how to use SearchApps API.
     */
    searchApps(searchAppsRequest: requests.SearchAppsRequest): Promise<responses.SearchAppsResponse>;
    /**
     * Search for Auth tokens using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchAuthTokensRequest
     * @return SearchAuthTokensResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchAuthTokens.ts.html |here} to see how to use SearchAuthTokens API.
     */
    searchAuthTokens(searchAuthTokensRequest: requests.SearchAuthTokensRequest): Promise<responses.SearchAuthTokensResponse>;
    /**
     * Search Authentication Factor Settings Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchAuthenticationFactorSettingsRequest
     * @return SearchAuthenticationFactorSettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchAuthenticationFactorSettings.ts.html |here} to see how to use SearchAuthenticationFactorSettings API.
     */
    searchAuthenticationFactorSettings(searchAuthenticationFactorSettingsRequest: requests.SearchAuthenticationFactorSettingsRequest): Promise<responses.SearchAuthenticationFactorSettingsResponse>;
    /**
     * Search for customer secret keys using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchCustomerSecretKeysRequest
     * @return SearchCustomerSecretKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchCustomerSecretKeys.ts.html |here} to see how to use SearchCustomerSecretKeys API.
     */
    searchCustomerSecretKeys(searchCustomerSecretKeysRequest: requests.SearchCustomerSecretKeysRequest): Promise<responses.SearchCustomerSecretKeysResponse>;
    /**
     * Search for Dynamic Resource Groups using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchDynamicResourceGroupsRequest
     * @return SearchDynamicResourceGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchDynamicResourceGroups.ts.html |here} to see how to use SearchDynamicResourceGroups API.
     */
    searchDynamicResourceGroups(searchDynamicResourceGroupsRequest: requests.SearchDynamicResourceGroupsRequest): Promise<responses.SearchDynamicResourceGroupsResponse>;
    /**
     * Search Grants Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchGrantsRequest
     * @return SearchGrantsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchGrants.ts.html |here} to see how to use SearchGrants API.
     */
    searchGrants(searchGrantsRequest: requests.SearchGrantsRequest): Promise<responses.SearchGrantsResponse>;
    /**
     * Search for groups using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchGroupsRequest
     * @return SearchGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchGroups.ts.html |here} to see how to use SearchGroups API.
     */
    searchGroups(searchGroupsRequest: requests.SearchGroupsRequest): Promise<responses.SearchGroupsResponse>;
    /**
     * Search Identity Providers Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchIdentityProvidersRequest
     * @return SearchIdentityProvidersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchIdentityProviders.ts.html |here} to see how to use SearchIdentityProviders API.
     */
    searchIdentityProviders(searchIdentityProvidersRequest: requests.SearchIdentityProvidersRequest): Promise<responses.SearchIdentityProvidersResponse>;
    /**
     * Search for Identity settings using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchIdentitySettingsRequest
     * @return SearchIdentitySettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchIdentitySettings.ts.html |here} to see how to use SearchIdentitySettings API.
     */
    searchIdentitySettings(searchIdentitySettingsRequest: requests.SearchIdentitySettingsRequest): Promise<responses.SearchIdentitySettingsResponse>;
    /**
     * Search KmsiSettings Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchKmsiSettingsRequest
     * @return SearchKmsiSettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchKmsiSettings.ts.html |here} to see how to use SearchKmsiSettings API.
     */
    searchKmsiSettings(searchKmsiSettingsRequest: requests.SearchKmsiSettingsRequest): Promise<responses.SearchKmsiSettingsResponse>;
    /**
     * Search My Apps Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchMyAppsRequest
     * @return SearchMyAppsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchMyApps.ts.html |here} to see how to use SearchMyApps API.
     */
    searchMyApps(searchMyAppsRequest: requests.SearchMyAppsRequest): Promise<responses.SearchMyAppsResponse>;
    /**
     * Search for 'My Groups' using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchMyGroupsRequest
     * @return SearchMyGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchMyGroups.ts.html |here} to see how to use SearchMyGroups API.
     */
    searchMyGroups(searchMyGroupsRequest: requests.SearchMyGroupsRequest): Promise<responses.SearchMyGroupsResponse>;
    /**
     * Search My Requestable Groups Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchMyRequestableGroupsRequest
     * @return SearchMyRequestableGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchMyRequestableGroups.ts.html |here} to see how to use SearchMyRequestableGroups API.
     */
    searchMyRequestableGroups(searchMyRequestableGroupsRequest: requests.SearchMyRequestableGroupsRequest): Promise<responses.SearchMyRequestableGroupsResponse>;
    /**
     * Search My Requests Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchMyRequestsRequest
     * @return SearchMyRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchMyRequests.ts.html |here} to see how to use SearchMyRequests API.
     */
    searchMyRequests(searchMyRequestsRequest: requests.SearchMyRequestsRequest): Promise<responses.SearchMyRequestsResponse>;
    /**
     * Search for OAuth2 client credentials using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchOAuth2ClientCredentialsRequest
     * @return SearchOAuth2ClientCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchOAuth2ClientCredentials.ts.html |here} to see how to use SearchOAuth2ClientCredentials API.
     */
    searchOAuth2ClientCredentials(searchOAuth2ClientCredentialsRequest: requests.SearchOAuth2ClientCredentialsRequest): Promise<responses.SearchOAuth2ClientCredentialsResponse>;
    /**
     * Search for password policies using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchPasswordPoliciesRequest
     * @return SearchPasswordPoliciesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchPasswordPolicies.ts.html |here} to see how to use SearchPasswordPolicies API.
     */
    searchPasswordPolicies(searchPasswordPoliciesRequest: requests.SearchPasswordPoliciesRequest): Promise<responses.SearchPasswordPoliciesResponse>;
    /**
     * Search Resource Type Schema Attributes Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchResourceTypeSchemaAttributesRequest
     * @return SearchResourceTypeSchemaAttributesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchResourceTypeSchemaAttributes.ts.html |here} to see how to use SearchResourceTypeSchemaAttributes API.
     */
    searchResourceTypeSchemaAttributes(searchResourceTypeSchemaAttributesRequest: requests.SearchResourceTypeSchemaAttributesRequest): Promise<responses.SearchResourceTypeSchemaAttributesResponse>;
    /**
     * Search for security question settings using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchSecurityQuestionSettingsRequest
     * @return SearchSecurityQuestionSettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchSecurityQuestionSettings.ts.html |here} to see how to use SearchSecurityQuestionSettings API.
     */
    searchSecurityQuestionSettings(searchSecurityQuestionSettingsRequest: requests.SearchSecurityQuestionSettingsRequest): Promise<responses.SearchSecurityQuestionSettingsResponse>;
    /**
     * Search for security questions using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchSecurityQuestionsRequest
     * @return SearchSecurityQuestionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchSecurityQuestions.ts.html |here} to see how to use SearchSecurityQuestions API.
     */
    searchSecurityQuestions(searchSecurityQuestionsRequest: requests.SearchSecurityQuestionsRequest): Promise<responses.SearchSecurityQuestionsResponse>;
    /**
     * Search for SMTP credentials using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchSmtpCredentialsRequest
     * @return SearchSmtpCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchSmtpCredentials.ts.html |here} to see how to use SearchSmtpCredentials API.
     */
    searchSmtpCredentials(searchSmtpCredentialsRequest: requests.SearchSmtpCredentialsRequest): Promise<responses.SearchSmtpCredentialsResponse>;
    /**
     * Search User Schema Attribute Settings Using POST
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchUserAttributesSettingsRequest
     * @return SearchUserAttributesSettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchUserAttributesSettings.ts.html |here} to see how to use SearchUserAttributesSettings API.
     */
    searchUserAttributesSettings(searchUserAttributesSettingsRequest: requests.SearchUserAttributesSettingsRequest): Promise<responses.SearchUserAttributesSettingsResponse>;
    /**
     * Search for a user's database (DB) credentials using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchUserDbCredentialsRequest
     * @return SearchUserDbCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchUserDbCredentials.ts.html |here} to see how to use SearchUserDbCredentials API.
     */
    searchUserDbCredentials(searchUserDbCredentialsRequest: requests.SearchUserDbCredentialsRequest): Promise<responses.SearchUserDbCredentialsResponse>;
    /**
     * Search for users using POST.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SearchUsersRequest
     * @return SearchUsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.68.1/identitydomains/SearchUsers.ts.html |here} to see how to use SearchUsers API.
     */
    searchUsers(searchUsersRequest: requests.SearchUsersRequest): Promise<responses.SearchUsersResponse>;
}
